% LaTeX class file for UKHTC
% CHANGES
% - 2021-03: Modified for UKHTC2021, Manchester, UK

% WARNING: This is a class file created to help you in preparing a full
% paper for UKHTC2021
% - It has not been thoroughly tested and thus will likely have bugs
% - It is provided as is. 

% -------------------------------------------------------------------
%    filename:  ukhtc2021.cls
%    date:      16 Apr 2021
%    usage:     \documentclass[options]{ukhtc2021}
% -------------------------------------------------------------------

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ukhtc2021}[2021/03/22 v1.0 UKHTC2021 Template Class]
\LoadClass[onecolumn,a4paper,11pt]{article}
\RequirePackage{times}
\RequirePackage{mathptm}
\RequirePackage{helvet}  % for header
\RequirePackage{graphicx} % for header image

% -------------------------------------------------------------------
%  AFFILIATION and AUTHOR HANDLING
% -------------------------------------------------------------------
\RequirePackage{authblk}
\renewcommand\Authfont{\fontsize{12.5}{12.5}\fontseries{b}\selectfont}
\renewcommand\Affilfont{\fontsize{11}{11}\fontseries{m}\selectfont}
\renewcommand*{\Authsep}{, }
\renewcommand*{\Authand}{, }
\renewcommand*{\Authands}{, }
\setlength{\affilsep}{10pt}

% -------------------------------------------------------------------
%  COMMON VARIABLES
% -------------------------------------------------------------------
% PAPER ID
\let\@paperid\relax
\def\paperid#1{\def\paperid{#1}}

% -------------------------------------------------------------------
%  FONT SIZES
% -------------------------------------------------------------------
\setlength\lineskip{1\p@}
\setlength\normallineskip{1\p@}
\renewcommand{\baselinestretch}{1}
\setlength{\baselineskip}{20pt plus 1pt minus 1pt}

\renewcommand\scriptsize{\@setfontsize\scriptsize{7}{i}}
\renewcommand\tiny{\@setfontsize\tiny{8}{8}}
\renewcommand\footnotesize{\@setfontsize\footnotesize{9}{9.5}}
\renewcommand\small{\@setfontsize\small{10}{10}}
\renewcommand\large{\@setfontsize\large{12}{12}}
\renewcommand\Large{\@setfontsize\Large{14}{14}}
\renewcommand\LARGE{\@setfontsize\LARGE{18}{18}}
\renewcommand\huge{\@setfontsize\huge{24}{24}}
\let\Huge=\huge

% -------------------------------------------------------------------
%  PAGE LAYOUT
% -------------------------------------------------------------------
\RequirePackage[left=25mm,right=25mm,top=30mm,bottom=30mm, headheight=20mm, headsep=0pt]{geometry}

% Indent the first line after a section
% Borrowed from the indentfirst package 
\let\@afterindentfalse\@afterindenttrue
\@afterindenttrue

\RequirePackage[indent=6mm]{parskip}

% -------------------------------------------------------------------
%  HEADERS and FOOTERS
% -------------------------------------------------------------------
\RequirePackage{fancyhdr}
\fancypagestyle{firstpage}{% \maketitle uses the plain style 
  \fancyhf{} % clear all header and footer styles
  \fancyhead[L]{%
    \parbox[b][\headheight][t]{0.5\textwidth}{%
      \includegraphics[height=1.5cm]{ukhtc2021-logo}%
    }%
    \@gobble% this is because fancyhead outputs a strut at the end, which we gobble
  }%
  \fancyhead[R]{%
    \fontfamily{phv}\fontsize{9.5pt}{\baselineskip}\selectfont%
    \parbox[b][\headheight][t]{0.5\textwidth}{%
      \raggedleft%
      \textbf{%
        17th UK Heat Transfer Conference (UKHTC2021)\\%
        4-6 April 2022, Manchester, UK%
      }%
    }%
    \@gobble% this is because fancyhead outputs a strut at the end, which we gobble
  }%
  \fancyfoot[L]{*Corresponding author: \@corresponding}
  %\fancyfoot[R]{\thepage}
  \renewcommand{\headrulewidth}{0pt} % no rules
  \renewcommand{\footrulewidth}{0pt} % no rules
  %\setlength{\headruleskip}{0pt} % no gap between head baseline and text
}
\fancypagestyle{plain}{%
  \fancyhf{} % clear all header and footer styles
  %\fancyfoot[R]{\thepage}
  \renewcommand{\headrulewidth}{0pt} % no rules
  \renewcommand{\footrulewidth}{0pt} % no rules
}
\pagestyle{plain}

% -------------------------------------------------------------------
%  TITLE PAGE
% -------------------------------------------------------------------
\renewcommand\title[1]{\gdef\@title{\uppercase{#1}}}  % set title to uppercase

\newcommand{\corresponding}[1]{%
  \def\@corresponding{#1}%
}
\makeatletter

\renewcommand*{\maketitle}{%
  \begingroup
    \newpage
    \global\@topnum\z@  % prevents figures from going to the top of the page
    \newpage
    \@gobble a%
    \vskip 0em%
    \begin{center}%
      {%
        %\fontsize{14}{14} \fontseries{b} \selectfont%
        \Large \bfseries \@title \par%
        \vskip 2pt%
      }%
      {%
        \@author \par%
        \vskip 10pt%
      }%
    \end{center}\par%
    \thispagestyle{firstpage}
    %\vskip 18pt%
    \gdef\@author{}\gdef\@title{}
  \endgroup
  \setcounter{footnote}{0}
  \global\let\corresponding\relax
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}
\makeatother

% -------------------------------------------------------------------
%  SECTION HEADINGS
% -------------------------------------------------------------------
\setcounter{secnumdepth}{2}
\makeatletter
\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   %{-3.5ex \@plus -1ex \@minus -.2ex}%
                                   {12pt}%
                                   {6pt}%
                                   {\normalfont\fontsize{12}{12}\bfseries\MakeUppercase}}
\renewcommand\subsection{\@startsection {subsection}{2}{\z@}%
                                   %{-3.5ex \@plus -1ex \@minus -.2ex}%
                                   {12pt}%
                                   {6pt}%
                                   {\normalfont\fontsize{12}{12}\bfseries}}

\renewcommand\subsubsection{\@startsection {subsubsection}{3}{\z@}%
                                   %{-3.5ex \@plus -1ex \@minus -.2ex}%
                                   {12pt}%
                                   {6pt}%
                                   {\normalfont\fontsize{12}{12}\itshape}}

\makeatother


% -------------------------------------------------------------------
%  ENVIRONMENTS
% -------------------------------------------------------------------

%renew the enumerate 
\addtolength\leftmargini{1em}%
\makeatletter
\let\@tempone\itemize
\let\@temptwo\enditemize
\renewenvironment{itemize}{%
  \@tempone%
  \setlength\labelsep{6mm}%
  \setlength\itemindent{0mm}%
  \setlength\itemsep{0pt}%
  \setlength\parskip{0pt}%
  \setlength\listparindent{0mm}}%
  {\@temptwo}%
\makeatother
% spacing for lists
\setlength{\topsep}{11pt}
\setlength{\parsep}{0pt}

% change the abstract environment to be a section heading
\makeatletter
\renewenvironment{abstract}{%
    \section*{\abstractname}
}%
{}
\makeatother

% adjust spacing for captions
\setlength\abovecaptionskip{11pt}
\setlength\belowcaptionskip{6pt}
\makeatletter
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{\small {\bfseries#1}: #2}%
  \ifdim \wd\@tempboxa >\hsize
    \small {\bfseries #1}: #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}
\makeatother

% helper command for centering table headings
\newcommand\Tstrut{\rule{0pt}{12pt}} % top strut
\newcommand\Bstrut{\rule[-6pt]{0pt}{0pt}} % top strut
\newcommand*{\thead}[1]{\multicolumn{1}{c}{#1\Tstrut\Bstrut}}

% spacing for bibliography styles
